##  Overview
In the Notifications Center section of the admin area, admin users can configure default notification settings for the workspace, defining how users get notified of workspace events.
The Notifications Center allows administrators to configure how the users of a workspace will receive notifications:
  * It allows to completely disable all notifications or certain channels
  * It allows to mute notifications triggered due to changes by technical users
  * It allows configuring, which topics users of the workspace may receive
    * By completely disabling certain topics
    * By enforcing certain topics to be received by all users
    * By limiting certain topics to only have some of the available options (never, instantly, daily, weekly)
  * It allows to setup & test of custom configuration for the E-Mail channel
    * Workspace branding to be used for the default header & footer
    * Custom header & footer (HTML)
    * Custom SMTP server
  * It allows to setup & test of custom configuration for the Microsoft Teams channel
    * Setup Bot & Microsoft Teams tenant ID
  * It offers an Audit Log that allows seeing which notifications have been sent recently


Users can customize their individual notification preferences in the Notifications section of their user settings. For more information, see [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.").
